@@ -10,7 +10,7 @@ appsettings$apptitle = "Confidence intervals"
 
 #name of underlying simulation function(s) to be used in the app
 #must be provided
-appsettings$simfunction = 'simulate_confint_fit'
+appsettings$simfunction = 'simulate_fit_confint'
 
 #number of plots to produce for output
 appsettings$nplots = 1
